@@ -1,11 +1,8 @@
-import os
-import json
-import numpy as np
-
 import re
 import dateutil.parser as date_parser
 import dateparser
 
+from collections import defaultdict
 
 #preprocessing cleaning operations
 DELETE = "delete"
@@ -17,9 +14,12 @@ H1, H2, H3, H4, H5 = "h1","h2","h3","h4","h5"
 DIVIDER = "divider"
 TITLE = "title"
 AUTHOR = "author"
+QUOTE_TEXT = "qtext"
+QUOTE_NAME = "qname"
+IMAGE = "image"
 
-MARK_COUNTERS = [H1, H2, H3, H4, H5, DIVIDER]
-MARK_META = [H1, H2, H3, H4, H5, DIVIDER, TITLE, AUTHOR]
+MARK_COUNTERS = [H1, H2, H3, H4, H5, DIVIDER, QUOTE_TEXT, QUOTE_NAME, IMAGE]
+MARK_META = [H1, H2, H3, H4, H5, DIVIDER, TITLE, AUTHOR, QUOTE_TEXT, QUOTE_NAME, IMAGE]
 
 PARAGRAPH_MARK = "%%%%%"
 LINE_ENDINGS = [".","!","?",";",":","。","？","！"] #”
@@ -143,7 +143,43 @@ def is_date(line):
 
 def mark_paragraphs(lines):
     line_endings = tuple([x for x in LINE_ENDINGS])
-    for i, line in enumerate(lines):
+    for i, line in enumerate(lines):        
+        line = line.strip()
         if line.endswith(line_endings):
             lines[i] = line[:-1] + PARAGRAPH_MARK + line[-1]
     return lines
+
+
+def parse_marked_line(line):
+    """Parse marked line for UI view"""
+    res = defaultdict(bool)
+    p_ending = tuple([PARAGRAPH_MARK + x for x in LINE_ENDINGS])    
+    if line.endswith(p_ending):
+        #remove last occurence of PARAGRAPH_MARK
+        line = ''.join(line.rsplit(PARAGRAPH_MARK, 1))
+        res["pa"] = True
+    for mark in MARK_META:
+        ending = f"{PARAGRAPH_MARK}{mark}."
+        if line.endswith(ending):
+            res[mark[:2]] = True
+            res["pa"] = False
+            line = line[:len(line)-len(ending)]
+    res["text"] = line
+    return res
+
+
+def extract_marks(res, line, ix):
+    """Extract marks information in exists"""
+    p_ending = tuple([PARAGRAPH_MARK + x for x in LINE_ENDINGS])    
+    if line.endswith(p_ending):
+        #remove last occurence of PARAGRAPH_MARK
+        line = ''.join(line.rsplit(PARAGRAPH_MARK, 1))
+    for mark in MARK_META:
+        ending = f"{PARAGRAPH_MARK}{mark}."
+        if line.endswith(ending):
+            res.append((line[:len(line)-len(ending)], ix, mark))
+    return res
+
+
+def get_all_meta_marks():
+    return [f"{PARAGRAPH_MARK}{m}" for m in MARK_META]
\ No newline at end of file
