@@ -1,7 +1,6 @@
 """Texts splitter part of the engine"""
 
 
-import os
 import re
 
 # import constants as con
@@ -29,6 +28,7 @@ XX_CODE = "xx"
 LANGUAGES = {
     RU_CODE: {"name": "Russian"},
     ZH_CODE: {"name": "Chinese"},
+    
     DE_CODE: {"name": "German"},
     EN_CODE: {"name": "English"},
     FR_CODE: {"name": "French"},
@@ -122,14 +122,27 @@ def get_substrings(line, sep, endings, res):
             res.append(line + sep)
 
 
-def split_by_sentences_wrapper(lines, langcode, leave_marks=False):
+def split_by_sentences_wrapper(lines, langcode):
     """Special wrapper with an additional paragraph splitting"""
-    sentences = ensure_paragraph_splitting(
-        split_by_sentences(lines, langcode, leave_marks))
-    return sentences
+    res, acc = [], []
+    marks = preprocessor.get_all_meta_marks()
+    for line in lines:
+        if any(m in line for m in marks):
+            print("found mark", line)
+            if acc:
+                sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode))
+                res.extend(sentences)
+                acc = []
+            res.append(line)
+        else:
+            acc.append(line)
+    if acc:
+        sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode))
+        res.extend(sentences)            
+    return res
 
 
-def split_by_sentences(lines, langcode, leave_marks=False):
+def split_by_sentences(lines, langcode):
     """Split line by sentences using language specific rules"""
     line = ' '.join(lines)
     if langcode == RU_CODE:
@@ -141,24 +154,18 @@ def split_by_sentences(lines, langcode, leave_marks=False):
         return sentences
     if langcode == DE_CODE:
         sentences = preprocess(line, [
-            (german_quotes, ''),
+            (german_quotes, '"'),
             *DEFAULT_PREPROCESSING
         ],
             split_by_razdel)
         return sentences
-    if langcode == ZH_CODE and leave_marks:
+    if langcode == ZH_CODE:
         sentences = preprocess(line, [
+            # (pat_comma, '。'),
             (pattern_zh, '')
         ],
             split_zh)
         return sentences
-    if langcode == ZH_CODE and not leave_marks:
-        sentences = preprocess(line, [
-            (pat_comma, '。'),
-            (pattern_zh_total, '')
-        ],
-            split_zh)
-        return sentences
     if langcode == JP_CODE:
         sentences = preprocess(line, [
             (pat_comma, '。'),
@@ -179,13 +186,17 @@ def split_by_sentences(lines, langcode, leave_marks=False):
     return sentences
 
 
-def split_by_sentences_and_save(raw_path, splitted_path, filename, langcode, username):
+def split_by_sentences_and_save(raw_path, splitted_path, langcode, handle_marks=False):
     """Split raw text file by sentences and save"""
-
     with open(raw_path, mode='r', encoding='utf-8') as input_file, open(splitted_path, mode='w', encoding='utf-8') as out_file:
         if is_lang_code_valid(langcode):
-            sentences = split_by_sentences(
-                input_file.readlines(), langcode)
+            lines = input_file.readlines()
+            if handle_marks:
+                lines = preprocessor.mark_paragraphs(lines)  
+                sentences = split_by_sentences_wrapper(
+                    lines, langcode)
+            else:
+                sentences = split_by_sentences(lines, langcode)
         else:
             raise Exception("Unknown language code.")
 
